#region Copyright Syncfusion Inc. 2001-2016.
// Copyright Syncfusion Inc. 2001-2016. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Syncfusion.Windows.Shared;
using Syncfusion.Windows.Tools.Controls;
using System.Runtime.Serialization.Formatters.Binary;
using System.Runtime.Serialization;
using System.Runtime.Serialization.Formatters.Soap;
using System.Xml;
using System.Windows.Forms.Integration;


namespace DocumentContainerDemo_2008
{
    
    public partial class Window1 : Window
    {
        #region Private Members
        /// <summary>
        /// String for Displaying in the MessageBox.
        /// </summary>
        private const string AttentionHeader = "Attention!";
        int i = 1;
        #endregion

        #region constructor
        /// <summary>
        /// Contructor for window1.
        /// </summary>
        public Window1()
        {
            InitializeComponent();          
        }
        #endregion
        
        #region Helper Methods  
        
        /// <summary>
        /// Method used for changing the TDI/MDI modes in runtime.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>    
        private void mode_Click(object sender, RoutedEventArgs e)
        {
            //Changing DocumentContianer Mode
            MenuItem c = (MenuItem)sender;
            string g = c.Header.ToString();           
            if (DocContainer != null)
            {
                if (g.StartsWith("MDI"))
                {
                    DocContainer.Mode = DocumentContainerMode.MDI;
                    TDI.IsChecked = false;
                    MDI.IsChecked = true;
                    layout.IsEnabled = true;
                    UISizer.IsEnabled = true;
                    
                }
                else if (g.StartsWith("TDI"))
                {
                    DocContainer.Mode = DocumentContainerMode.TDI;
                   
                    TDI.IsChecked = true;
                    MDI.IsChecked = false;
                    UISizer.IsEnabled = false;
                    layout.IsEnabled = false;
                    UISizer.Value = 1;                 
                                     
                }
            }
        }
        /// <summary>
        /// Method used for changing the Layout for the MDI elements.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>  
        private void Layout_Click(object sender, RoutedEventArgs e)
        {
            //Changing Document Containter Layout
            MenuItem c = (MenuItem)sender;
            string g = c.Header.ToString();
            switch (c.Name)
            {
                case "Cascade":
                    DocContainer.SetLayout(MDILayout.Cascade);
                    break;
                case "THorizontal":
                    DocContainer.SetLayout(MDILayout.Horizontal);
                    break;
                case "TVertical":
                    DocContainer.SetLayout(MDILayout.Vertical);
                    break;
            }            
        }
        /// <summary>
        /// Method used for saving the states to Registry.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>  
     
        private void OnSaveToRegStateClick(object sender, RoutedEventArgs e)
        {           
            //Save State
            BinaryFormatter formatter1 = new BinaryFormatter();
            DocContainer.SaveDockState(formatter1);           
        }

        /// <summary>
        /// Method used for Load the states from Registry.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>  

        private void OnLoadFromRegStateClick(object sender, RoutedEventArgs e)
        {          
            //Load State
            BinaryFormatter formatter1 = new BinaryFormatter();
            try
            {
                DocContainer.LoadDockState(formatter1);
            }
            catch (SerializationException ex)
            {
                MessageBox.Show(ex.Message, AttentionHeader, MessageBoxButton.OK, MessageBoxImage.Warning);
            }
            catch (FormatException ex)
            {
                MessageBox.Show(ex.Message, AttentionHeader, MessageBoxButton.OK, MessageBoxImage.Warning);
            }
        }
        /// <summary>
        /// Method used for saving the states to IS.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>  
        private void OnSaveStateToIsoStorageClick(object sender, RoutedEventArgs e)
        {
            //Save State to Isolated Storage
            DocContainer.SaveDockState();
        }
        /// <summary>
        /// Method used for Load the states from IS.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>  
        private void OnLoadStateFromIsoStorageClick(object sender, RoutedEventArgs e)
        {
            //Load State from Isolated Storage
            DocContainer.LoadDockState();
        }
        /// <summary>
        /// Method used for reset the states from IS.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>  
        private void OnResetStateInIsoStorageClick(object sender, RoutedEventArgs e)
        {
           //Delete Internal Isolated Storage
            DocContainer.DeleteInternalIsolatedStorage();
        }
        /// <summary>
        /// Method used for saving the states to XML.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>  
        private void OnSaveToXMLStateClick(object sender, RoutedEventArgs e)
        {
           //Save to XML sate
            if (BinFormatterRadio.IsChecked == true)
            {
                BinaryFormatter formatter1 = new BinaryFormatter();
                DocContainer.SaveDockState(formatter1, StorageFormat.Xml, 
                    AppDomain.CurrentDomain.BaseDirectory.ToString() + "\\docum_xml.xml");
            }
            else
            {
                SoapFormatter formatter1 = new SoapFormatter();
                DocContainer.SaveDockState(formatter1, StorageFormat.Xml, 
                    AppDomain.CurrentDomain.BaseDirectory.ToString() + "\\docum_xml.xml");
            }
        }
        /// <summary>
        /// Method used for Load the states from XML.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>  
        private void OnLoadFromXMLStateClick(object sender, RoutedEventArgs e)
        {
           //Load from XML State
            if (BinFormatterRadio.IsChecked == true)
            {
                BinaryFormatter formatter1 = new BinaryFormatter();
                try
                {
                    DocContainer.LoadDockState(formatter1, StorageFormat.Xml,
                        AppDomain.CurrentDomain.BaseDirectory.ToString() + "\\docum_xml.xml");
                }
                catch (XmlException ex)
                {
                    MessageBox.Show(ex.Message, AttentionHeader, MessageBoxButton.OK, 
                                                                 MessageBoxImage.Warning);
                }
                catch (InvalidOperationException ex)
                {
                    MessageBox.Show(ex.Message, AttentionHeader, MessageBoxButton.OK, 
                                                                 MessageBoxImage.Warning);
                }
            }
            else
            {
                SoapFormatter formatter1 = new SoapFormatter();
                try
                {
                    DocContainer.LoadDockState(formatter1, StorageFormat.Xml, 
                        AppDomain.CurrentDomain.BaseDirectory.ToString() + "\\docum_xml.xml");
                }
                catch (XmlException ex)
                {
                    MessageBox.Show(ex.Message, AttentionHeader, MessageBoxButton.OK, 
                                                                 MessageBoxImage.Warning);
                }
                catch (InvalidOperationException ex)
                {
                    MessageBox.Show(ex.Message, AttentionHeader, MessageBoxButton.OK,
                                                                 MessageBoxImage.Warning);
                }
            }
        }
        /// <summary>
        /// Method used for saving the states to Binary.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>  
        private void OnSaveToBinStateClick(object sender, RoutedEventArgs e)
        {
            //Save to Binary State   
            if (BinFormatterRadio.IsChecked == true)
            {
                BinaryFormatter formatter1 = new BinaryFormatter();
                DocContainer.SaveDockState(formatter1, StorageFormat.Binary, 
                    AppDomain.CurrentDomain.BaseDirectory.ToString() + "\\docum_bin.bin");
            }
            else
            {
                SoapFormatter formatter1 = new SoapFormatter();
                DocContainer.SaveDockState(formatter1, StorageFormat.Binary, 
                    AppDomain.CurrentDomain.BaseDirectory.ToString() + "\\docum_bin.bin");
            }
        }
        /// <summary>
        /// Method used for Load the states from Binary.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>  
        private void OnLoadFromBinStateClick(object sender, RoutedEventArgs e)
        { 
            //Load from Binary State
            if (BinFormatterRadio.IsChecked == true)
            {
                BinaryFormatter formatter1 = new BinaryFormatter();
                try
                {
                    DocContainer.LoadDockState(formatter1, StorageFormat.Binary, 
                        AppDomain.CurrentDomain.BaseDirectory.ToString() + "\\docum_bin.bin");
                }
                catch (SerializationException ex)
                {
                    MessageBox.Show(ex.Message, AttentionHeader, MessageBoxButton.OK,
                                                                 MessageBoxImage.Warning);
                }
                catch (XmlException ex)
                {
                    MessageBox.Show(ex.Message, AttentionHeader, MessageBoxButton.OK, 
                                                                 MessageBoxImage.Warning);
                }
            }
            else
            {
                SoapFormatter formatter1 = new SoapFormatter();
                try
                {
                   DocContainer.LoadDockState(formatter1, StorageFormat.Binary, 
                       AppDomain.CurrentDomain.BaseDirectory.ToString() + "\\docum_bin.bin");
                }
                catch (XmlException ex)
                {
                    MessageBox.Show(ex.Message, AttentionHeader, MessageBoxButton.OK, 
                                                                 MessageBoxImage.Warning);
                }
            }
        }
        /// <summary>
        /// Method used for Reset the States.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>  
        private void OnResetStateClick(object sender, RoutedEventArgs e)
        {           
            //Reset State
            DocContainer.ResetState();            
        }
        /// <summary>
        /// Method used for Deleting the states.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>  
        private void deletestate_Click(object sender, RoutedEventArgs e)
        {
            //Delete Dock State
            DocContainer.DeleteDockState(AppDomain.CurrentDomain.BaseDirectory.ToString() + "\\docum_xml.xml");
            DocContainer.DeleteDockState(AppDomain.CurrentDomain.BaseDirectory.ToString() + "\\docum_bin.bin");
            DocContainer.DeleteDockState();
        }
        /// <summary>
        /// Method used to add elements to the Document Container.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>  
        private void AddElement_Click(object sender, RoutedEventArgs e)
        {           
           //RichTextBox rtb = new RichTextBox();
           //DocumentContainer.SetHeader(rtb, "New 4 Window" + i.ToString());
           //Rect re = new Rect(30, 30, 300, 300);
           //DocumentContainer.SetMDIBounds(rtb, re);
           //DocContainer.Items.Add(rtb);
           //DocContainer.ActiveDocument = rtb;
          // i++;

            MessageBox.Show("ok");


          //  UserControl1 uc1 = new UserControl1();
          //  System.Windows.Forms.Integration.WindowsFormsHost host = new System.Windows.Forms.Integration.WindowsFormsHost();
          //  host.Child = uc1;// // uu; //uc1;//propertyGrid;
          //  grid.Children.Add(host);


          // Window1 rtb = new Window1();
          //// RichTextBox rtb = new RichTextBox();
          // DocumentContainer.SetHeader(rtb, "New 4 Window" + i.ToString());
          // Rect re = new Rect(30, 30, 300, 300);
          // DocumentContainer.SetMDIBounds(rtb, re);
          // DocContainer.Items.Add(rtb);
          // DocContainer.ActiveDocument = rtb;
          // i++;    





        }
         /// <summary>
        /// Method used to close the window.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>  
        private void Close_Click(object sender, RoutedEventArgs e)
        {
            this.Close();
        }
        /// <summary>
        /// Method used to change the different window switchers.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>   
        private void windowswitchers_Click(object sender, RoutedEventArgs e)
        {
            //Changing SwitchMode
            MenuItem mi = (MenuItem)e.OriginalSource;
            string g = mi.Header.ToString();
            gbVistaFlip.Visibility = Visibility.Collapsed;
            for (int i = 0; i < WindowSwitchers.Items.Count; i++)
            {
                MenuItem mitem = (MenuItem)WindowSwitchers.Items[i];
                if (mitem.Header.ToString().Equals(g))
                    mitem.IsChecked = true;
                else
                    mitem.IsChecked = false;
            }
            if (g.StartsWith("Immediate"))
                DocContainer.SwitchMode = SwitchMode.Immediate;
            else if (g.StartsWith("List"))
                DocContainer.SwitchMode = SwitchMode.List;
            else if (g.StartsWith("QuickTabs"))
                DocContainer.SwitchMode = SwitchMode.QuickTabs;
            else if (g.StartsWith("VS2005"))
                DocContainer.SwitchMode = SwitchMode.VS2005;
            else if (g.StartsWith("VistaFlip"))
            {
                DocContainer.SwitchMode = SwitchMode.VistaFlip;
                gbVistaFlip.Visibility = Visibility.Visible;              
            }
        }
        /// <summary>
        /// Method used to close.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>  
        private void Close_CanExecute(object sender, CanExecuteRoutedEventArgs e)
        {
            e.CanExecute = true;
        }
        #endregion

        private void AddElementWPF_Click(object sender, RoutedEventArgs e)
        {
            MessageBox.Show("ok WPF");
          
            Window1 rtb1 = new Window1();
            // RichTextBox rtb = new RichTextBox();
            DocumentContainer.SetHeader(rtb1, "New WPF" + i.ToString());
            Rect re = new Rect(30, 30, 300, 300);
            DocumentContainer.SetMDIBounds(rtb1, re);
            DocContainer.Items.Add(rtb1);
            DocContainer.ActiveDocument = rtb1;
            i++; 
        }

    

        private void AddElementWF_Click(object sender, RoutedEventArgs e)
        {
            //RichTextBox rtb = new RichTextBox();
            //DocumentContainer.SetHeader(rtb, "New 4 Window" + i.ToString());
            //Rect re = new Rect(30, 30, 300, 300);
            //DocumentContainer.SetMDIBounds(rtb, re);
            //DocContainer.Items.Add(rtb);
            //DocContainer.ActiveDocument = rtb;
            // i++;

            MessageBox.Show("ok WF");

          
            UserControl1 rtb = new UserControl1();
            System.Windows.Forms.Integration.WindowsFormsHost host = new System.Windows.Forms.Integration.WindowsFormsHost();
            //host.Child = rtb;
            //grid.Children.Add(host);


             
            // RichTextBox rtb = new RichTextBox();
            DocumentContainer.SetHeader(rtb, "New WF" + i.ToString());
            Rect re = new Rect(30, 30, 300, 300);
            DocumentContainer.SetMDIBounds(rtb, re);
            DocContainer.Items.Add(rtb);
            DocContainer.ActiveDocument = rtb;
            i++;  
        }

        private void AddElementWUC_Click(object sender, RoutedEventArgs e)
        {
            MessageBox.Show("ok UC");
            UserControl1 rtb3 = new UserControl1();
            System.Windows.Forms.Integration.WindowsFormsHost host = new System.Windows.Forms.Integration.WindowsFormsHost();
             host.Child = rtb3;
            // grid.Children.Add(host);
             DocContainer.Items.Add(host);

            DocumentContainer.SetHeader(rtb3, "New UC" + i.ToString());
            Rect re = new Rect(30, 30, 300, 300);
            DocumentContainer.SetMDIBounds(rtb3, re);
            DocContainer.Items.Add(rtb3);
            DocContainer.ActiveDocument = rtb3;
            i++; 

        }
    }
}
   